<template>
  <div>
    <div v-if="this.$route.name === 'snack_shopmain'">
      <h1>Recent Sales</h1>
      <table id="RecentSales">
        <thead>
          <tr>
            <th>Time</th>
            <th>To</th>
            <th>Account Number</th>
            <th>Amount</th>
          </tr>
        </thead>
        <tbody v-if="recentTransactions.length">
          <tr
            v-for="(transaction, index) in recentTransactions"
            :key="index">
            <td>{{ moment.utc(transaction.time).local().format("h:mm a") }}</td>
            <td>{{ transaction.account_name }}</td>
            <td v-if="transaction.from && !transaction.to">{{ transaction.from }}</td>
            <td v-else-if="transaction.to && !transaction.from">{{ transaction.to }}</td>
            <td v-else>{{ transaction.from }}</td>
            <td v-if="transaction.amount">${{ transaction.amount.toFixed(2) }}</td>
          </tr>
        </tbody>
        <tbody v-else>
          <tr>
            <td colspan="4">No Transactions Yet!</td>
          </tr>
          <tr/>
        </tbody>
      </table>
    </div>
    <div v-else>
      <ul
        v-if="recentTransactions.length"
        class="transactionslist">
        <li
          v-for="(transaction, index) in recentTransactions"
          :key="index">
          <!-- <h2>{{transaction.account_name}}</h2> -->
          <!-- <p>{{transaction.name}}</p> -->
          <p>
            <b>From:</b>
            {{ transaction.account_name }}
          </p>
          <p v-if="transaction.from && !transaction.to">
            <b>Account Number:</b>
            {{ transaction.from }}
          </p>
          <p v-else-if="transaction.to && !transaction.from">
            <b>Account Number:</b>
            {{ transaction.to }}
          </p>
          <p v-else>
            <b>Account Number:</b>
            {{ transaction.from }}
          </p>
          <p v-if="transaction.amount">
            <b>Amount:</b>
            ${{ transaction.amount.toFixed(2) }}
          </p>
          <p>
            <b>Time:</b>
            {{ moment.utc(transaction.time).local().format("h:mm a") }}
          </p>
        </li>
      </ul>
      <ul
        v-else
        class="transactionslist">
        <li>
          <p style="list-style: none;">
            <b>No Transactions Yet!</b>
          </p>
        </li>
      </ul>
    </div>
  </div>
</template>

<script>
export default {
  props: {
    shop: Object
  },
  data() {
    return {
      recentTransactions: [],
      intervalID: ""
    };
  },
  destroyed: function() {
    clearInterval(this.intervalID);
  },
  created: function() {
    this.getRecentTransactions();
    // this.intervalID = setInterval(() => {
    //   if(this.shop){
    //     this.getRecentTransactions();
    //   }
    // }, 5000);
    app.webhook.transactionChannel.bind("RecentTransactions", data => {
      // app.Message('Recent Transactions Updated', 'success');
      this.getRecentTransactions();
    });
  },
  methods: {
    getRecentTransactions() {
      app.api
        .Get(`transaction/getRecent/${this.shop.canonical_name}`)
        .then(response => {
          this.recentTransactions = response;
        })
        .catch(x => app.Message(x.error, "error"));
    }
  },
};
</script>